@@ -1863,6 +1863,33 @@ class Api(object):
     results.append(self.PostUpdate(lines[-1], **kwargs))
     return results
 
+  def PostRetweet(self, tweet_id):
+    '''Retweet a tweet with the Retweet API
+
+    The twitter.Api instance must be authenticated.
+
+    Args:
+      id: The numerical ID of the tweet you are retweeting
+      
+    Returns:
+      A twitter.Status instance representing the retweet posted
+    '''
+    if not self._username:
+      raise TwitterError("The twitter.Api instance must be authenticated.")
+    try:
+        if int(tweet_id) <= 0:
+            raise TwitterError("'id' must be a positive number")
+    except ValueError:
+        raise TwitterError("'id' must be an integer")
+        
+    data = {'id': tweet_id}
+    url = '%s/statuses/retweet/%s.json' % (self.base_url,tweet_id)
+#    url = 'http://api.twitter.com/1/statuses/retweet/%s.json' % tweet_id
+    json = self._FetchUrl(url, post_data=data)
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return Status.NewFromJsonDict(data)
+
   def GetReplies(self, since=None, since_id=None, page=None): 
     '''Get a sequence of status messages representing the 20 most recent
     replies (status updates prefixed with @username) to the authenticating
@@ -2516,8 +2543,8 @@ class Api(object):
     else:
       http_method = "GET"
 
-    http_handler  = self._urllib.HTTPHandler(debuglevel=1)
-    https_handler = self._urllib.HTTPSHandler(debuglevel=1)
+    http_handler  = self._urllib.HTTPHandler(debuglevel=0)
+    https_handler = self._urllib.HTTPSHandler(debuglevel=0)
 
     opener = self._urllib.OpenerDirector()
     opener.add_handler(http_handler)
@@ -2672,4 +2699,4 @@ class _FileCache(object):
                         hashed_key)
 
   def _GetPrefix(self,hashed_key):
-    return os.path.sep.join(hashed_key[0:_FileCache.DEPTH])
\ No newline at end of file
+    return os.path.sep.join(hashed_key[0:_FileCache.DEPTH])
